@@ -1,7 +1,7 @@
 package Validator::Custom;
 use Object::Simple -base;
 use 5.008001;
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Carp 'croak';
 use Validator::Custom::Validation;
@@ -269,8 +269,7 @@ sub _parse_constraint {
 # DEPRECATED!
 has shared_rule => sub { [] };
 # DEPRECATED!
-__PACKAGE__->dual_attr('constraints',
-  default => sub { {} }, inherit => 'hash_copy');
+__PACKAGE__->attr('constraints' => sub { {} });
 
 # Version 0 method
 sub create_rule { Validator::Custom::Rule->new(validator => shift) }
@@ -770,11 +769,13 @@ EOS
 
 1;
 
+=encoding UTF-8
+
 =head1 NAME
 
 Validator::Custom - HTML form Validation, simple and good flexibility
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
   use Validator::Custom;
   my $vc = Validator::Custom->new;
@@ -919,7 +920,7 @@ You can use C<int> checking function to check the value is integer.
 C<int> checking function is default one.
 Any checking function is available through C<check> method.
 
-When the check dosen't success, you can add failed parameter name and the message
+When the check doesn't succeed, you can add the failed parameter name and the message
 using C<add_failed> method of L<Validator::Custom::Validation> class.
   
   # Filter price to remove left-rigth space
@@ -1366,12 +1367,12 @@ C<decimal> constraint is renamed to C<number> checking function and simplified.
 
 =item *
 
-C<date_to_timepiece> checking function dosen't exist.
+C<date_to_timepiece> checking function doesn't exist.
 About alternative way, see the topic "Convert date string to Time::Piece object" in "EXAMPLES".
 
 =item *
 
-C<datetime_to_timepiece> checking function dosen't exists.
+C<datetime_to_timepiece> checking function doesn't exists.
 About alternative way, see the topic "Convert datetime string to Time::Piece object" in "EXAMPLES".
 
 =back
